summaryrefslogtreecommitdiff
path: root/inc
diff options
context:
space:
mode:
authorborekb <borekb@gmail.com>2013-01-30 21:51:39 +0100
committerAndreas Gohr <andi@splitbrain.org>2013-02-03 21:12:48 +0100
commit58bedc8a310955dbc00e738bec1dc4f442eaff4e (patch)
treed72407d0e560577ec927068892c0920e66b08290 /inc
parent5ed76064a702b3f1c4191c5bb0b59f408d6af238 (diff)
downloadrpg-58bedc8a310955dbc00e738bec1dc4f442eaff4e.tar.gz
rpg-58bedc8a310955dbc00e738bec1dc4f442eaff4e.tar.bz2
Updated idfilter() function for IIS
There is a condition inside idfilter() function that helps Apache on Windows to properly handle colon as a namespace separator by replacing it with semicolon. However, this is not necessary on Microsoft IIS server so the condition was improved.
Diffstat (limited to 'inc')
-rw-r--r--inc/common.php5
1 files changed, 3 insertions, 2 deletions
diff --git a/inc/common.php b/inc/common.php
index bc49e76b2..a270e4eaf 100644
--- a/inc/common.php
+++ b/inc/common.php
@@ -311,7 +311,7 @@ function breadcrumbs() {
*
* This is run on a ID before it is outputted somewhere
* currently used to replace the colon with something else
* on Windows systems and to have proper URL encoding
*
* Urlencoding is ommitted when the second parameter is false
*
@@ -322,7 +322,8 @@ function idfilter($id, $ue = true) {
if($conf['useslash'] && $conf['userewrite']) {
$id = strtr($id, ':', '/');
} elseif(strtoupper(substr(PHP_OS, 0, 3)) === 'WIN' &&
- $conf['userewrite']
+ $conf['userewrite'] &&
+ strpos($_SERVER['SERVER_SOFTWARE'], 'Microsoft-IIS') === false
) {
$id = strtr($id, ':', ';');
}
@@ -311,7 +311,7 @@ function breadcrumbs() {
* This is run on a ID before it is outputted somewhere
* currently used to replace the colon with something else
- * on Windows systems and to have proper URL encoding
+ * on Windows non-IIS systems and to have proper URL encoding
*
* Urlencoding is ommitted when the second parameter is false